@@ -15,11 +15,14 @@ class IMUFactory:
     """Factory that creates IMU object from given IMU type."""
 
     @staticmethod
-    def detect_and_create(i2c_id: I2CBusID | None = None) -> list[IMUManager]:
+    def detect_and_create(
+        i2c_id: I2CBusID | None = None, log_data: bool = False
+    ) -> list[IMUManager]:
         """Automatically detect addresses and create sensor managers.
 
         :param i2c_id: I2C bus identifier. If None, attempt to use board.I2C().
         :return: list of SensorManager instances.
+        :param log_data: Flag to record the IMU data
         """
         imu_managers: list[IMUManager] = []
 
@@ -30,7 +33,11 @@ class IMUFactory:
             config = IMUDevices.from_address(addr)
             if config:
                 imu_wrapper = IMUWrapper(config=config, i2c_bus=i2c_bus)
-                imu_managers.append(IMUManager(imu_wrapper=imu_wrapper, i2c_id=i2c_id))
+                imu_managers.append(
+                    IMUManager(
+                        imu_wrapper=imu_wrapper, i2c_id=i2c_id, log_data=log_data
+                    )
+                )
                 logger.info(f"Detected {config} at I2C address '{addr}'.")
 
         return imu_managers
